clear all; close all;
% This is a demo script, showing how to use presented quartz response
% function to extract THz electric field transients

addpath('./Quartz response function/');
addpath('./Test data/');
addpath('./sub/');

%% Load demo data
data_Q = load('Fig3a_EOS_AbsoluteExperimental.txt'); % Load a 50um Quartz EOS trace
t = data_Q(:,1);
S = data_Q(:,2)*1e-3; % rad
d = 50e-6; % m; z-cut quartz thickness

figure(); % Plot the trace
plot(t, S);
xlabel('Time (ps)');
ylabel('Quartz EOS signal (rad)');
xlim([-5, 5]);

%% Fourier transform the raw data to go to frequency-domain, correct by the response function
[omega, Fx] = ft_eq(t, S); % Fourier transform the raw data to frequency domain
hQ = det_Q(transpose(omega)*1e12, d).'; % Set up the response function for 50um Quartz

Ex = Fx./hQ; % Extract the electric field in frequency space
Ex(isnan(Ex))=0; % There will be some NaN values due to zeros in hQ. Set them to zero, otherwise the inverse Fourier transform will not work.

% There will also be high-frequency noise due to devision by 0 in the response function, when there is noise in the raw signal. 
% So you may want to filter this out. The cut-off point depends on your THz source.
boxc = boxcar_window(omega, 2*pi*6).'; % One option is to use a boxcar window and just set the values to zero, where you don't expect any more THz source signal.

% To accurately remove the quartz 4 THz resonance, you might have to play with the specific chi2 values (C, omega_TO, gamma_TO) to get the best result.
% An alternative is to use an apodization as a window function (instead of boxcar) to reduce the high-frequency noise and impact of the 4 THz phonon response discrepency. 
apod = [zeros(length(omega(omega<-2*pi*7)),1); apodization(omega(abs(omega)<2*pi*7), 2); zeros(length(omega(omega>2*pi*7)),1)]; % This will not affect the shape of your single-cycle pulse. 

%Ex = Ex.*boxc; % Apply the boxcar to the electric field
Ex = Ex.*apod; % or apply the apodization (window) function to the electric field

figure(); % Plot the EOS spectrum and the extracted THz field spectrum
plot(omega/(2*pi), abs(Fx)/max(abs(Fx)));
hold on;
plot(omega/(2*pi), abs(Ex)/max(abs(Ex(abs(omega)<10))));
xlim([0, 5]);
legend('EOS spectrum', 'THz field spectrum');
xlabel('Frequency (THz)');
ylabel('Spectrum (norm.)');

%% Fourier transform back to the time-domain and plot the result
[t_new, S_new] = ift_eq(omega, Ex); % Fourier transform back to the time-domain
t_c = time_correct(t_new, real(S_new)); % time0 correct the data

figure();
plot(t_c, real(S_new)/(1e8)); % The electric field is real.
xlabel('Time (ps)');
ylabel('Extracted THz electric field (MV/cm)');
xlim([-5, 5]);