function [omega, Fx] = ft_eq(t,x,flag)
% [omega, Fx] = ft_eq(t,x[,flag])
% fourier transformation Fx of signal x = x(t);
% x(t) has to be sampled on an equispaced
% t mesh with spacing dt (offset is ignored and set to 0);
% returns spectrum [omega Fx] 
% where omega = 0 is centered (flag=1, default) or lowest frequency (flag = 0)
% signals should fulfill the Nyquist condition;
% basis functions are exp(-i*omega*t)/sqrt(2*pi)! (not +i);
% if x is a matrix, operation is performed column-wise

if nargin < 3
    flag = 1;
end
[N, M] = size(x);           % M columns

% calculate spacings and periodicities
dt = (t(N) -t(1))/(N-1);
T = N*dt;
% T = (t(N) -t(1))*N/(N-1);
% dt = T/N;
domega = 2*pi/T;
Omega = N*domega;

% columnwise DFT, t(1) ignored (set to 0)
Fx = ifft(x) *sqrt(2*pi)*N/Omega; % hin-trafo mit +i statt -i

% compose spectrum properly
omega = (0:N-1).'*domega; % if lowest omega = 0
if flag
    N2 = floor(N/2);
    N1 = N2 -N+1;
    Fx = [Fx(N2+2:N,:); Fx(1:N2+1,:)]; % if symmetrical around omega = 0
    omega = (N1:N2).' *domega;
end

% % compose spectrum properly
% omega = (0:N-1).'*domega; % if lowest omega = 0
% N2 = round(N/2);
% N1 = N2 -N;
% if flag
%     Fx = [Fx(N2+1:N,:); Fx(1:N2,:)]; % if symmetrical around omega = 0
%     omega = (N1:N2-1).' *domega;
% end